library(xlsx)
library(ggplot2)
library(survival)
library(FSA)

# Set working directory (using the current directory of script file)
setwd(dirname(parent.frame(2)$ofile))


# Load the data for RQ1
loadDataRQ1 <- function(){
  DataRQ1 <<- read.xlsx("Data.xlsx", "RQ1")
}

# Generate the boxplot
boxPlotRQ1 <- function(){
  ggplot(data=DataRQ1, aes(Application, DeprecatedAPIUsages, fill=Application)) + theme(legend.position = "none" ) + geom_boxplot() + ylab("# Deprecated API Usages") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
}

# Compute the desciptive statistics
statsRQ1 <- function(){
  summary <- Summarize(DeprecatedAPIUsages~Application, data=DataRQ1, digits=3)
  print(summary)
} 

# Load the data for RQ2 and RQ3
loadDataRQ2AndRQ3 <- function(){
  DataRQ2AndRQ3 <<- read.xlsx("Data.xlsx", "RQ2-3")
}

# Perform the survival analysis in terms of commits
survivalAnalysisByCommit <- function(){
  model.commits <<- survfit(Surv(SurvivalTimeCommits, Status) ~ Application, data = DataRQ2AndRQ3)
  print(model.commits)
}

# Perform the survival analysis in terms of days
survivalAnalysisByDay <- function(){
  model.days <<- survfit(Surv(SurvivalTimeDays, Status) ~ Application, data = DataRQ2AndRQ3)
  print(model.days)
}

# Generate the barplot
barPlotRQ3 <- function(){
  
  abs.freq.tab <- table(DataRQ2AndRQ3$Application, DataRQ2AndRQ3$APILocation)
  rel.freq.tab <<- prop.table(abs.freq.tab, 1)
  DataInternal <<- as.data.frame(rel.freq.tab)
  
  colnames(DataInternal)[1] <<- "Application" 
  colnames(DataInternal)[2] <<- "Location" 
  
  DataInternal <- DataInternal[which(DataInternal$Freq != 0), ]
  rel.freq.tab <<- prop.table(abs.freq.tab, 1)
  
  ggplot(DataInternal, aes(x = Application, y = Freq, fill = Location)) + geom_col(position = "fill") +  scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Consumed Deprecated APIs") +
    theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1)) + geom_text(aes(label = paste(round(Freq * 100, 0), "%", sep="")), colour = "white", size = 3, vjust = 1.5, position = position_fill(.9))
  
}

# Load the data for RQ4 regarding the introductions of deprecated API usages
loadDataRQ4A <- function(){
  DataRQ4A <<- read.xlsx("Data.xlsx", "RQ4.A")
}

# Generate the barplot
barPlotRQ4A <- function(){ # 6 x 4
  
  DataRQ4A <- DataRQ4A[which(DataRQ4A$X.Introcuctions != 0), ]
  
  plot <- ggplot(DataRQ4A, aes(x = Application, y = X.Introcuctions, fill = Developer)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Introductions") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))

  plot <- plot + geom_text(
    aes(label = paste(round(X.Introcuctions.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 1.5, position = position_fill(.9)
  )
  
  show(plot)
}

# Load the data for RQ3 regarding the removals of deprecated API usages
loadDataRQ4B <- function(){
  DataRQ4B <<- read.xlsx("Data.xlsx", "RQ4.B")
}

# Generate the barplot
barPlotRQ4B <- function(){
  DataRQ4B <- DataRQ4B[which(DataRQ4B$X.Removals != 0), ]
  plot <- ggplot(DataRQ4B, aes(x = Application, y = X.Removals, fill = Developer)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Removals") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
  
  plot <- plot + geom_text(
    aes(label = paste(round(X.Removals.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 1.5, position = position_fill(.9)
  )
  
  show(plot)
}

# Load the data for RQ5 regarding the introductions of deprecated API usages
loadDataRQ5A <- function(){
  DataRQ5A <<- read.xlsx("Data.xlsx", "RQ5.A")
}

# Generate the barplot
barPlotRQ5A <- function(){
  
  custom.col <- c("#90e0ef", "#00b4d8", "#0077b6", "#03045e")
  
  DataRQ5A <- DataRQ5A[which(DataRQ5A$X.Introductions.1 != 0), ]
  
  
  plot <- ggplot(DataRQ5A, aes(x = Application, y = X.Introductions.1, fill = Quarter)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Introductions") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
  
  plot <- plot + geom_text(
    aes(label = paste(round(X.Introductions.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 0.8, position = position_fill(.9)
  )
  
  plot <- plot + scale_fill_manual(values=custom.col) + labs(fill = "Quarter")
  
  show(plot)
}

# Load the data for RQ5 regarding the removals of deprecated API usages
loadDataRQ5B <- function(){
  DataRQ5B <<- read.xlsx("Data.xlsx", "RQ5.B")
}

# Generate the barplot
barPlotRQ5BDays <- function(){
  
  custom.col <- c("#90e0ef", "#00b4d8", "#0077b6", "#03045e")
  
  DataRQ5B <- DataRQ5B[which(DataRQ5B$X.Removals.1 != 0), ]
  
  
  plot <- ggplot(DataRQ5B, aes(x = Application, y = X.Removals.1, fill = Quarter)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Removals") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))

  plot <- plot + geom_text(
    aes(label = paste(round(X.Removals.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 0.8, position = position_fill(.8)
  )
  
  plot <- plot + scale_fill_manual(values=custom.col) + labs(fill = "Quarter")
  
  show(plot)
}

# Load the data for RQ5 (further analysis)
loadDataRQ5Further <- function(){
  DataRQ5Further <<- read.xlsx("Data.xlsx", "RQ5.Further")
}

# Generate the boxplot
boxPlotRQ5Further <- function(){
  ggplot(data=DataRQ5Further, aes(Application, DeprecatedAPIUsages)) + theme(legend.position = "top" ) + geom_boxplot(aes(fill=Tagged)) + ylab("# Deprecated API Usages") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
}

# Load the data for RQ6 on documenting the introductions of deprecated API usages
loadDataRQ6A <- function(){
  DataRQ6A <<- read.xlsx("Data.xlsx", "RQ6.A")
}

# Generate the barplot
barPlotRQ6A <- function(){ 
  
  DataRQ6A <- DataRQ6A[which(DataRQ6A$X.Introductions.1 != 0), ]
  
  plot <- ggplot(DataRQ6A, aes(x = Application, y = X.Introductions.1, fill = Class)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Introductions") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
  
  plot <- plot + geom_text(
    aes(label = paste(round(X.Introductions.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 1.0, position = position_fill(.7)
  )
  
  plot <- plot + labs(fill = "Class")
  
  show(plot)
}

# Load the data for RQ6 on documenting the introductions of deprecated API usages
loadDataRQ6B <- function(){
  DataRQ6B <<- read.xlsx("Data.xlsx", "RQ6.B")
}

# Generate the barplot
barPlotRQ6B <- function(){ # 6 x 5.5
  
  DataRQ6B <- DataRQ6B[which(round(DataRQ6B$X.Removals.1,0) != 0), ]
  
  plot <- ggplot(DataRQ6B, aes(x = Application, y = X.Removals.1, fill = Class)) + geom_col(position = "fill") + scale_y_continuous(labels = scales::percent) + theme(legend.position = "top") + ylab("% Removals") + theme(axis.text.x = element_text(angle = 90, vjust = 0.7, hjust=1))
  
  plot <- plot + geom_text(
    aes(label = paste(round(X.Removals.1,0), "%", sep = "")),
    colour = "white", size = 3,
    vjust = 1.0, position = position_fill(.6)
  )
  
  plot <- plot + labs(fill = "Class")
  
  
  show(plot)
}

